@@ -15,21 +15,21 @@ from javascript_data_files.decoder import decode_from_json
         '[{ "nested": { "sides": 3, "sides": 4 } }]',
     ],
 )
-def test_object_with_duplicate_keys_is_rejected(json_string: str) -> None:
+def test_object_with_duplicate_names_is_rejected(json_string: str) -> None:
     """
     Trying to decode a JavaScript string which includes an object
-    with duplicate keys throws a ValueError.
+    with duplicate names throws a ValueError.
     """
-    with pytest.raises(ValueError, match="Found duplicate key in JSON object: sides"):
+    with pytest.raises(ValueError, match="Found duplicate name in JSON object: sides"):
         decode_from_json(json_string)
 
 
-def test_object_with_multiple_duplicate_keys_is_rejected() -> None:
+def test_object_with_multiple_duplicate_names_is_rejected() -> None:
     """
     Trying to decode a JavaScript string which includes an object
-    with multiple duplicate keys throws a ValueError.
+    with multiple duplicate names throws a ValueError.
     """
-    with pytest.raises(ValueError, match="Found duplicate keys in JSON object:"):
+    with pytest.raises(ValueError, match="Found duplicate names in JSON object:"):
         decode_from_json(
             '{ "sides": 3, "colour": "blue", "sides": 4, "colour": "red" }'
         )
